@@ -10,11 +10,11 @@ import (
 var Args = tt.Args
 
 func TestIsReadErrorRecoverable(t *testing.T) {
-	tt.Test(t, tt.Fn("IsReadErrorRecoverable", IsReadErrorRecoverable), tt.Table{
+	tt.Test(t, IsReadErrorRecoverable,
 		Args(seqError{}).Rets(true),
 		Args(ErrStopped).Rets(true),
 		Args(errTimeout).Rets(true),
 
 		Args(errors.New("other error")).Rets(false),
-	})
+	)
 }
