@@ -4,9 +4,10 @@ import (
 	"src.elv.sh/pkg/diag"
 	"src.elv.sh/pkg/eval"
 	"src.elv.sh/pkg/parse"
+	"src.elv.sh/pkg/parse/np"
 )
 
-var completers = []func(nodePath, *eval.Evaler, Config) (*context, []RawItem, error){
+var completers = []func(np.Path, *eval.Evaler, Config) (*context, []RawItem, error){
 	completeCommand,
 	completeIndex,
 	completeRedir,
@@ -21,63 +22,63 @@ type context struct {
 	interval diag.Ranging
 }
 
-func completeArg(np nodePath, ev *eval.Evaler, cfg Config) (*context, []RawItem, error) {
+func completeArg(p np.Path, ev *eval.Evaler, cfg Config) (*context, []RawItem, error) {
 	var form *parse.Form
-	if np.match(aSep, store(&form)) && form.Head != nil {
+	if p.Match(np.Sep, np.Store(&form)) && form.Head != nil {
 		// Case 1: starting a new argument.
-		ctx := &context{"argument", "", parse.Bareword, range0(np[0].Range().To)}
-		args := purelyEvalForm(form, "", np[0].Range().To, ev)
-		items, err := generateArgs(args, ev, np, cfg)
+		ctx := &context{"argument", "", parse.Bareword, range0(p[0].Range().To)}
+		args := purelyEvalForm(form, "", p[0].Range().To, ev)
+		items, err := generateArgs(args, ev, p, cfg)
 		return ctx, items, err
 	}
 
-	expr := simpleExpr(ev)
-	if np.match(expr, store(&form)) && form.Head != nil && form.Head != expr.compound {
+	var expr np.SimpleExprData
+	if p.Match(np.SimpleExpr(&expr, ev), np.Store(&form)) && form.Head != nil && form.Head != expr.Compound {
 		// Case 2: in an incomplete argument.
-		ctx := &context{"argument", expr.s, expr.quote, expr.compound.Range()}
-		args := purelyEvalForm(form, expr.s, expr.compound.Range().From, ev)
-		items, err := generateArgs(args, ev, np, cfg)
+		ctx := &context{"argument", expr.Value, expr.PrimarType, expr.Compound.Range()}
+		args := purelyEvalForm(form, expr.Value, expr.Compound.Range().From, ev)
+		items, err := generateArgs(args, ev, p, cfg)
 		return ctx, items, err
 	}
 
 	return nil, nil, errNoCompletion
 }
 
-func completeCommand(np nodePath, ev *eval.Evaler, cfg Config) (*context, []RawItem, error) {
+func completeCommand(p np.Path, ev *eval.Evaler, cfg Config) (*context, []RawItem, error) {
 	generateForEmpty := func(pos int) (*context, []RawItem, error) {
 		ctx := &context{"command", "", parse.Bareword, range0(pos)}
-		items, err := generateCommands("", ev, np)
+		items, err := generateCommands("", ev, p)
 		return ctx, items, err
 	}
 
-	if np.match(aChunk) {
+	if p.Match(np.Chunk) {
 		// Case 1: The leaf is a Chunk. That means that the chunk is empty
 		// (nothing entered at all) and it is a correct place for completing a
 		// command.
-		return generateForEmpty(np[0].Range().To)
+		return generateForEmpty(p[0].Range().To)
 	}
-	if np.match(aSep, aChunk) || np.match(aSep, aPipeline) {
+	if p.Match(np.Sep, np.Chunk) || p.Match(np.Sep, np.Pipeline) {
 		// Case 2: Just after a newline, semicolon, or a pipe.
-		return generateForEmpty(np[0].Range().To)
+		return generateForEmpty(p[0].Range().To)
 	}
 
 	var primary *parse.Primary
-	if np.match(aSep, store(&primary)) {
+	if p.Match(np.Sep, np.Store(&primary)) {
 		t := primary.Type
 		if t == parse.OutputCapture || t == parse.ExceptionCapture || t == parse.Lambda {
 			// Case 3: At the beginning of output, exception capture or lambda.
 			//
 			// TODO: Don't trigger after "{|".
-			return generateForEmpty(np[0].Range().To)
+			return generateForEmpty(p[0].Range().To)
 		}
 	}
 
-	expr := simpleExpr(ev)
+	var expr np.SimpleExprData
 	var form *parse.Form
-	if np.match(expr, store(&form)) && form.Head == expr.compound {
+	if p.Match(np.SimpleExpr(&expr, ev), np.Store(&form)) && form.Head == expr.Compound {
 		// Case 4: At an already started command.
-		ctx := &context{"command", expr.s, expr.quote, expr.compound.Range()}
-		items, err := generateCommands(expr.s, ev, np)
+		ctx := &context{"command", expr.Value, expr.PrimarType, expr.Compound.Range()}
+		items, err := generateCommands(expr.Value, ev, p)
 		return ctx, items, err
 	}
 
@@ -86,30 +87,30 @@ func completeCommand(np nodePath, ev *eval.Evaler, cfg Config) (*context, []RawI
 
 // NOTE: This now only supports a single level of indexing; for instance,
 // $a[<Tab> is supported, but $a[x][<Tab> is not.
-func completeIndex(np nodePath, ev *eval.Evaler, cfg Config) (*context, []RawItem, error) {
+func completeIndex(p np.Path, ev *eval.Evaler, cfg Config) (*context, []RawItem, error) {
 	generateForEmpty := func(v any, pos int) (*context, []RawItem, error) {
 		ctx := &context{"index", "", parse.Bareword, range0(pos)}
 		return ctx, generateIndices(v), nil
 	}
 
 	var indexing *parse.Indexing
-	if np.match(aSep, store(&indexing)) || np.match(aSep, aArray, store(&indexing)) {
+	if p.Match(np.Sep, np.Store(&indexing)) || p.Match(np.Sep, np.Array, np.Store(&indexing)) {
 		// We are at a new index, either directly after the opening bracket, or
 		// after an existing index and some spaces.
 		if len(indexing.Indices) == 1 {
 			if indexee := ev.PurelyEvalPrimary(indexing.Head); indexee != nil {
-				return generateForEmpty(indexee, np[0].Range().To)
+				return generateForEmpty(indexee, p[0].Range().To)
 			}
 		}
 	}
 
-	expr := simpleExpr(ev)
-	if np.match(expr, aArray, store(&indexing)) {
+	var expr np.SimpleExprData
+	if p.Match(np.SimpleExpr(&expr, ev), np.Array, np.Store(&indexing)) {
 		// We are just after an incomplete index.
 		if len(indexing.Indices) == 1 {
 			if indexee := ev.PurelyEvalPrimary(indexing.Head); indexee != nil {
 				ctx := &context{
-					"index", expr.s, expr.quote, expr.compound.Range()}
+					"index", expr.Value, expr.PrimarType, expr.Compound.Range()}
 				return ctx, generateIndices(indexee), nil
 			}
 		}
@@ -118,27 +119,27 @@ func completeIndex(np nodePath, ev *eval.Evaler, cfg Config) (*context, []RawIte
 	return nil, nil, errNoCompletion
 }
 
-func completeRedir(np nodePath, ev *eval.Evaler, cfg Config) (*context, []RawItem, error) {
-	if np.match(aSep, aRedir) {
+func completeRedir(p np.Path, ev *eval.Evaler, cfg Config) (*context, []RawItem, error) {
+	if p.Match(np.Sep, np.Redir) {
 		// Empty redirection target.
-		ctx := &context{"redir", "", parse.Bareword, range0(np[0].Range().To)}
+		ctx := &context{"redir", "", parse.Bareword, range0(p[0].Range().To)}
 		items, err := generateFileNames("", false)
 		return ctx, items, err
 	}
 
-	expr := simpleExpr(ev)
-	if np.match(expr, aRedir) {
+	var expr np.SimpleExprData
+	if p.Match(np.SimpleExpr(&expr, ev), np.Redir) {
 		// Non-empty redirection target.
-		ctx := &context{"redir", expr.s, expr.quote, expr.compound.Range()}
-		items, err := generateFileNames(expr.s, false)
+		ctx := &context{"redir", expr.Value, expr.PrimarType, expr.Compound.Range()}
+		items, err := generateFileNames(expr.Value, false)
 		return ctx, items, err
 	}
 
 	return nil, nil, errNoCompletion
 }
 
-func completeVariable(np nodePath, ev *eval.Evaler, cfg Config) (*context, []RawItem, error) {
-	primary, ok := np[0].(*parse.Primary)
+func completeVariable(p np.Path, ev *eval.Evaler, cfg Config) (*context, []RawItem, error) {
+	primary, ok := p[0].(*parse.Primary)
 	if !ok || primary.Type != parse.Variable {
 		return nil, nil, errNoCompletion
 	}
@@ -152,7 +153,7 @@ func completeVariable(np nodePath, ev *eval.Evaler, cfg Config) (*context, []Raw
 		diag.Ranging{From: begin, To: primary.Range().To}}
 
 	var items []RawItem
-	eachVariableInNs(ev, np, ns, func(varname string) {
+	eachVariableInNs(ev, p, ns, func(varname string) {
 		items = append(items, noQuoteItem(parse.QuoteVariableName(varname)))
 	})
 	if ns == "" {
