@@ -132,6 +132,8 @@ func emitRegionsInForm(n *parse.Form, f func(parse.Node, regionKind, string)) {
 	switch head {
 	case "var", "set", "tmp":
 		emitRegionsInAssign(n, f)
+	case "del":
+		emitRegionsInDel(n, f)
 	case "if":
 		emitRegionsInIf(n, f)
 	case "for":
@@ -155,6 +157,12 @@ func emitRegionsInAssign(n *parse.Form, f func(parse.Node, regionKind, string))
 	}
 }
 
+func emitRegionsInDel(n *parse.Form, f func(parse.Node, regionKind, string)) {
+	for _, arg := range n.Args {
+		emitVariableRegion(arg, f)
+	}
+}
+
 func emitVariableRegion(n *parse.Compound, f func(parse.Node, regionKind, string)) {
 	// Only handle valid LHS here. Invalid LHS will result in a compile error
 	// and highlighted as an error accordingly.
