@@ -12,7 +12,7 @@ var Args = tt.Args
 func TestGetRegions(t *testing.T) {
 	lsCommand := region{0, 2, semanticRegion, commandRegion}
 
-	tt.Test(t, tt.Fn("getRegionsFromString", getRegionsFromString), tt.Table{
+	tt.Test(t, getRegionsFromString,
 		Args("").Rets([]region(nil)),
 		Args("ls").Rets([]region{
 			lsCommand,
@@ -84,6 +84,13 @@ func TestGetRegions(t *testing.T) {
 			{8, 11, lexicalRegion, barewordRegion}, // foo
 		}),
 
+		// The "del" special command
+		Args("del x y").Rets([]region{
+			{0, 3, semanticRegion, commandRegion},  // tmp
+			{4, 5, semanticRegion, variableRegion}, // x
+			{6, 7, semanticRegion, variableRegion}, // y
+		}),
+
 		// The "if" special command.
 
 		Args("if x { }").Rets([]region{
@@ -210,7 +217,7 @@ func TestGetRegions(t *testing.T) {
 			{16, 17, lexicalRegion, "{"},
 			{18, 19, lexicalRegion, "}"},
 		}),
-	})
+	)
 }
 
 func getRegionsFromString(code string) []region {
