@@ -8,15 +8,6 @@ import (
 	"src.elv.sh/pkg/eval/vars"
 )
 
-//elvdoc:fn insert-at-dot
-//
-// ```elvish
-// edit:insert-at-dot $text
-// ```
-//
-// Inserts the given text at the dot, moving the dot after the newly
-// inserted text.
-
 func insertAtDot(app cli.App, text string) {
 	codeArea, ok := focusedCodeArea(app)
 	if !ok {
@@ -27,14 +18,6 @@ func insertAtDot(app cli.App, text string) {
 	})
 }
 
-//elvdoc:fn replace-input
-//
-// ```elvish
-// edit:replace-input $text
-// ```
-//
-// Equivalent to assigning `$text` to `$edit:current-command`.
-
 func replaceInput(app cli.App, text string) {
 	codeArea, ok := focusedCodeArea(app)
 	if !ok {
@@ -45,29 +28,16 @@ func replaceInput(app cli.App, text string) {
 	})
 }
 
-//elvdoc:var -dot
-//
-// Contains the current position of the cursor, as a byte position within
-// `$edit:current-command`.
-
-//elvdoc:var current-command
-//
-// Contains the content of the current input. Setting the variable will
-// cause the cursor to move to the very end, as if `edit-dot = (count
-// $edit:current-command)` has been invoked.
-//
-// This API is subject to change.
-
 func initStateAPI(app cli.App, nb eval.NsBuilder) {
 	// State API always operates on the root CodeArea widget
 	codeArea := app.ActiveWidget().(tk.CodeArea)
 
-	nb.AddGoFns(map[string]interface{}{
+	nb.AddGoFns(map[string]any{
 		"insert-at-dot": func(s string) { insertAtDot(app, s) },
 		"replace-input": func(s string) { replaceInput(app, s) },
 	})
 
-	setDot := func(v interface{}) error {
+	setDot := func(v any) error {
 		var dot int
 		err := vals.ScanToGo(v, &dot)
 		if err != nil {
@@ -78,12 +48,12 @@ func initStateAPI(app cli.App, nb eval.NsBuilder) {
 		})
 		return nil
 	}
-	getDot := func() interface{} {
+	getDot := func() any {
 		return vals.FromGo(codeArea.CopyState().Buffer.Dot)
 	}
 	nb.AddVar("-dot", vars.FromSetGet(setDot, getDot))
 
-	setCurrentCommand := func(v interface{}) error {
+	setCurrentCommand := func(v any) error {
 		var content string
 		err := vals.ScanToGo(v, &content)
 		if err != nil {
@@ -92,7 +62,7 @@ func initStateAPI(app cli.App, nb eval.NsBuilder) {
 		replaceInput(app, content)
 		return nil
 	}
-	getCurrentCommand := func() interface{} {
+	getCurrentCommand := func() any {
 		return vals.FromGo(codeArea.CopyState().Buffer.Content)
 	}
 	nb.AddVar("current-command", vars.FromSetGet(setCurrentCommand, getCurrentCommand))
