@@ -4,7 +4,7 @@ import "errors"
 
 var errNotSupportedOnWindows = errors.New("not supported on Windows")
 
-func execFn(...interface{}) error {
+func execFn(...any) error {
 	return errNotSupportedOnWindows
 }
 
