@@ -2,10 +2,15 @@ package eval
 
 import (
 	"errors"
+	"math"
+	"math/big"
 	"sync"
 	"sync/atomic"
 
+	"golang.org/x/sync/semaphore"
+
 	"src.elv.sh/pkg/errutil"
+	"src.elv.sh/pkg/eval/errs"
 	"src.elv.sh/pkg/eval/vals"
 )
 
@@ -73,16 +78,34 @@ func each(fm *Frame, f Callable, inputs Inputs) error {
 	return err
 }
 
-func peach(fm *Frame, f Callable, inputs Inputs) error {
+type peachOpt struct{ NumWorkers vals.Num }
+
+func (o *peachOpt) SetDefaultOptions() { o.NumWorkers = math.Inf(1) }
+
+func peach(fm *Frame, opts peachOpt, f Callable, inputs Inputs) error {
 	var wg sync.WaitGroup
 	var broken int32
 	var errMu sync.Mutex
 	var err error
 
+	var workerSema *semaphore.Weighted
+	numWorkers, limited, err := parseNumWorkers(opts.NumWorkers)
+	if err != nil {
+		return err
+	}
+	if limited {
+		workerSema = semaphore.NewWeighted(int64(numWorkers))
+	}
+
+	ctx := fm.Context()
+
 	inputs(func(v any) {
 		if atomic.LoadInt32(&broken) != 0 {
 			return
 		}
+		if workerSema != nil {
+			workerSema.Acquire(ctx, 1)
+		}
 		wg.Add(1)
 		go func() {
 			newFm := fm.Fork("closure of peach")
@@ -104,18 +127,47 @@ func peach(fm *Frame, f Callable, inputs Inputs) error {
 				}
 			}
 			wg.Done()
+			if workerSema != nil {
+				workerSema.Release(1)
+			}
 		}()
 	})
 	wg.Wait()
 	return err
 }
 
+func parseNumWorkers(n vals.Num) (int, bool, error) {
+	switch n := n.(type) {
+	case int:
+		if n >= 1 {
+			return n, true, nil
+		}
+	case *big.Int:
+		// A limit larger than MaxInt is equivalent to no limit.
+		return 0, false, nil
+	case float64:
+		if math.IsInf(n, 1) {
+			return 0, false, nil
+		}
+	}
+	return 0, false, errs.BadValue{
+		What:   "peach &num-workers",
+		Valid:  "exact positive integer or +inf",
+		Actual: vals.ToString(n),
+	}
+}
+
 // FailError is an error returned by the "fail" command.
 type FailError struct{ Content any }
 
+var _ vals.PseudoMap = FailError{}
+
 // Error returns the string representation of the cause.
 func (e FailError) Error() string { return vals.ToString(e.Content) }
 
+// Kind returns "fail-error".
+func (FailError) Kind() string { return "fail-error" }
+
 // Fields returns a structmap for accessing fields from Elvish.
 func (e FailError) Fields() vals.StructMap { return failFields{e} }
 
