@@ -1,6 +1,7 @@
 package eval
 
 import (
+	"context"
 	"fmt"
 	"os"
 	"sync"
@@ -37,7 +38,7 @@ func (op chunkOp) exec(fm *Frame) Exception {
 	// Check for interrupts after the chunk.
 	// We also check for interrupts before each pipeline, so there is no
 	// need to check it before the chunk or after each pipeline.
-	if fm.IsInterrupted() {
+	if fm.Canceled() {
 		return fm.errorp(op, ErrInterrupted)
 	}
 	return nil
@@ -67,13 +68,13 @@ type pipelineOp struct {
 const pipelineChanBufferSize = 32
 
 func (op *pipelineOp) exec(fm *Frame) Exception {
-	if fm.IsInterrupted() {
+	if fm.Canceled() {
 		return fm.errorp(op, ErrInterrupted)
 	}
 
 	if op.bg {
 		fm = fm.Fork("background job" + op.source)
-		fm.intCh = nil
+		fm.ctx = context.Background()
 		fm.background = true
 		fm.Evaler.addNumBgJobs(1)
 	}
@@ -522,21 +523,37 @@ func (op *redirOp) exec(fm *Frame) Exception {
 		fm.ports[dst] = fileRedirPort(op.mode, f, true)
 	case vals.File:
 		fm.ports[dst] = fileRedirPort(op.mode, src, false)
-	case vals.Pipe:
-		var f *os.File
+	case vals.Map, vals.StructMap:
+		var srcFile *os.File
 		switch op.mode {
 		case parse.Read:
-			f = src.ReadEnd
+			v, err := vals.Index(src, "r")
+			f, ok := v.(*os.File)
+			if err != nil || !ok {
+				return fm.errorp(op.srcOp, errs.BadValue{
+					What:   "map for input redirection",
+					Valid:  "map with file in the 'r' field",
+					Actual: vals.ReprPlain(src)})
+			}
+			srcFile = f
 		case parse.Write:
-			f = src.WriteEnd
+			v, err := vals.Index(src, "w")
+			f, ok := v.(*os.File)
+			if err != nil || !ok {
+				return fm.errorp(op.srcOp, errs.BadValue{
+					What:   "map for output redirection",
+					Valid:  "map with file in the 'w' field",
+					Actual: vals.ReprPlain(src)})
+			}
+			srcFile = f
 		default:
-			return fm.errorpf(op, "can only use < or > with pipes")
+			return fm.errorpf(op, "can only use < or > with maps")
 		}
-		fm.ports[dst] = fileRedirPort(op.mode, f, false)
+		fm.ports[dst] = fileRedirPort(op.mode, srcFile, false)
 	default:
 		return fm.errorp(op.srcOp, errs.BadValue{
 			What:  "redirection source",
-			Valid: "string, file or pipe", Actual: vals.Kind(src)})
+			Valid: "string, file or map", Actual: vals.Kind(src)})
 	}
 	return nil
 }
