@@ -2,6 +2,7 @@ package eval
 
 import (
 	"bufio"
+	"context"
 	"fmt"
 	"io"
 	"os"
@@ -25,7 +26,16 @@ type Frame struct {
 	local, up *Ns
 	defers    *[]func(*Frame) Exception
 
-	intCh <-chan struct{}
+	// The godoc of the context package states:
+	//
+	// > Do not store Contexts inside a struct type; instead, pass a Context
+	// > explicitly to each function that needs it.
+	//
+	// However, that advice is considered by many to be overly aggressive
+	// (https://github.com/golang/go/issues/22602). The Frame struct doesn't fit
+	// the "parameter struct" definition in that discussion, but it is itself is
+	// a "context struct". Storing a Context inside it seems fine.
+	ctx   context.Context
 	ports []*Port
 
 	traceback *StackTrace
@@ -56,7 +66,7 @@ func (fm *Frame) PrepareEval(src parse.Source, r diag.Ranger, ns *Ns) (*Ns, func
 		traceback = fm.addTraceback(r)
 	}
 	newFm := &Frame{
-		fm.Evaler, src, local, new(Ns), nil, fm.intCh, fm.ports, traceback, fm.background}
+		fm.Evaler, src, local, new(Ns), nil, fm.ctx, fm.ports, traceback, fm.background}
 	op, _, err := compile(fm.Evaler.Builtin().static(), local.static(), nil, tree, fm.ErrorFile())
 	if err != nil {
 		return nil, nil, err
@@ -165,6 +175,21 @@ func linesToChan(r io.Reader, ch chan<- any) {
 	}
 }
 
+// Context returns a Context associated with the Frame.
+func (fm *Frame) Context() context.Context {
+	return fm.ctx
+}
+
+// Canceled reports whether the Context of the Frame has been canceled.
+func (fm *Frame) Canceled() bool {
+	select {
+	case <-fm.ctx.Done():
+		return true
+	default:
+		return false
+	}
+}
+
 // Fork returns a modified copy of fm. The ports are forked, and the name is
 // changed to the given value. Other fields are copied shallowly.
 func (fm *Frame) Fork(name string) *Frame {
@@ -177,7 +202,7 @@ func (fm *Frame) Fork(name string) *Frame {
 	return &Frame{
 		fm.Evaler, fm.srcMeta,
 		fm.local, fm.up, fm.defers,
-		fm.intCh, newPorts,
+		fm.ctx, newPorts,
 		fm.traceback, fm.background,
 	}
 }
@@ -249,7 +274,7 @@ func (fm *Frame) Deprecate(msg string, ctx *diag.Context, minLevel int) {
 		ctx = fm.traceback.Head
 	}
 	if fm.Evaler.registerDeprecation(deprecation{ctx.Name, ctx.Ranging, msg}) {
-		err := diag.Error{Type: "deprecation", Message: msg, Context: *ctx}
+		err := diag.Error[deprecationTag]{Message: msg, Context: *ctx}
 		fm.ErrorFile().WriteString(err.Show("") + "\n")
 	}
 }
