@@ -10,8 +10,8 @@ import (
 var Args = tt.Args
 
 func TestMakeMap_PanicsWithOddNumberOfArguments(t *testing.T) {
-	tt.Test(t, tt.Fn("Recover", testutil.Recover), tt.Table{
+	tt.Test(t, testutil.Recover,
 		//lint:ignore SA5012 testing panic
 		Args(func() { MakeMap("foo") }).Rets("odd number of arguments to MakeMap"),
-	})
+	)
 }
