@@ -2,12 +2,10 @@ package fsutil
 
 import (
 	"os"
-	"path/filepath"
+	"runtime"
 	"strings"
 )
 
-var pathSep = string(filepath.Separator)
-
 // Getwd returns path of the working directory in a format suitable as the
 // prompt.
 func Getwd() string {
@@ -30,7 +28,7 @@ func TildeAbbr(path string) string {
 	if err == nil {
 		if path == home {
 			return "~"
-		} else if strings.HasPrefix(path, home+pathSep) {
+		} else if strings.HasPrefix(path, home+"/") || (runtime.GOOS == "windows" && strings.HasPrefix(path, home+"\\")) {
 			return "~" + path[len(home):]
 		}
 	}
