@@ -8,10 +8,11 @@ import (
 	"src.elv.sh/pkg/mods/file"
 	"src.elv.sh/pkg/mods/flag"
 	"src.elv.sh/pkg/mods/math"
+	"src.elv.sh/pkg/mods/os"
 	"src.elv.sh/pkg/mods/path"
 	"src.elv.sh/pkg/mods/platform"
 	"src.elv.sh/pkg/mods/re"
-	"src.elv.sh/pkg/mods/readlinebinding"
+	readline_binding "src.elv.sh/pkg/mods/readline-binding"
 	"src.elv.sh/pkg/mods/runtime"
 	"src.elv.sh/pkg/mods/str"
 	"src.elv.sh/pkg/mods/unix"
@@ -19,8 +20,8 @@ import (
 
 // AddTo adds all standard library modules to the Evaler.
 //
-// All the public properties of the Evaler should be set before this function is
-// called.
+// Some modules (the runtime module for now) may rely on properties set on the
+// Evaler, so any mutations afterwards may not be properly reflected.
 func AddTo(ev *eval.Evaler) {
 	ev.AddModule("runtime", runtime.Ns(ev))
 	ev.AddModule("math", math.Ns)
@@ -31,9 +32,10 @@ func AddTo(ev *eval.Evaler) {
 	ev.AddModule("file", file.Ns)
 	ev.AddModule("flag", flag.Ns)
 	ev.AddModule("doc", doc.Ns)
+	ev.AddModule("os", os.Ns)
 	if unix.ExposeUnixNs {
 		ev.AddModule("unix", unix.Ns)
 	}
 	ev.BundledModules["epm"] = epm.Code
-	ev.BundledModules["readline-binding"] = readlinebinding.Code
+	ev.BundledModules["readline-binding"] = readline_binding.Code
 }
