@@ -2,7 +2,6 @@
 package re
 
 import (
-	_ "embed"
 	"regexp"
 
 	"src.elv.sh/pkg/eval"
@@ -18,13 +17,9 @@ var Ns = eval.BuildNsNamed("re").
 		"find":    find,
 		"replace": replace,
 		"split":   split,
+		"awk":     eval.Eawk,
 	}).Ns()
 
-// DElvCode contains the content of the .d.elv file for this module.
-//
-//go:embed *.d.elv
-var DElvCode string
-
 type matchOpts struct{ Posix bool }
 
 func (*matchOpts) SetDefaultOptions() {}
