@@ -4,7 +4,6 @@ package str
 
 import (
 	"bytes"
-	_ "embed"
 	"fmt"
 	"strconv"
 	"strings"
@@ -23,7 +22,8 @@ var Ns = eval.BuildNsNamed("str").
 		"contains-any": strings.ContainsAny,
 		"count":        strings.Count,
 		"equal-fold":   strings.EqualFold,
-		// TODO: Fields, FieldsFunc
+		// TODO: FieldsFunc
+		"fields":          strings.Fields,
 		"from-codepoints": fromCodepoints,
 		"from-utf8-bytes": fromUtf8Bytes,
 		"has-prefix":      strings.HasPrefix,
@@ -55,11 +55,6 @@ var Ns = eval.BuildNsNamed("str").
 		"trim-suffix": strings.TrimSuffix,
 	}).Ns()
 
-// DElvCode contains the content of the .d.elv file for this module.
-//
-//go:embed *.d.elv
-var DElvCode string
-
 func fromCodepoints(nums ...int) (string, error) {
 	var b bytes.Buffer
 	for _, num := range nums {
