@@ -5,7 +5,6 @@ import (
 	"reflect"
 	"strconv"
 	"testing"
-	"time"
 
 	"src.elv.sh/pkg/persistent/hash"
 )
@@ -73,10 +72,6 @@ func hex(i uint64) string {
 	return "0x" + strconv.FormatUint(i, 16)
 }
 
-func init() {
-	rand.Seed(time.Now().UTC().UnixNano())
-}
-
 var randomStrings []string
 
 // getRandomStrings returns a slice of N3 random strings. It builds the slice
