@@ -1,6 +1,7 @@
 package prog_test
 
 import (
+	"errors"
 	"fmt"
 	"os"
 	"testing"
@@ -33,7 +34,10 @@ func TestFlagHandling(t *testing.T) {
 func TestLogFlag(t *testing.T) {
 	testutil.InTempDir(t)
 	Test(t, &testProgram{},
-		ThatElvish("-log", "log").DoesNothing())
+		ThatElvish("-log", "log").DoesNothing(),
+		ThatElvish("-log", "bad/log").WritesStderrContaining("open bad/log:"),
+	)
+
 	_, err := os.Stat("log")
 	if err != nil {
 		t.Errorf("log file was not created: %v", err)
@@ -57,7 +61,7 @@ func TestSharedFlags(t *testing.T) {
 func TestSharedFlags_MultiplePrograms(t *testing.T) {
 	Test(t,
 		Composite(
-			&testProgram{sharedFlags: true, nextProgram: true},
+			&testProgram{sharedFlags: true, returnErr: NextProgram()},
 			&testProgram{sharedFlags: true}),
 		ThatElvish("-sock", "sock", "-db", "db", "-json").
 			WritesStdout("-sock sock -db db -json true\n"),
@@ -65,7 +69,7 @@ func TestSharedFlags_MultiplePrograms(t *testing.T) {
 }
 
 func TestShowDeprecations(t *testing.T) {
-	progtest.SetDeprecationLevel(t, 0)
+	testutil.Set(t, &DeprecationLevel, 0)
 
 	Test(t, &testProgram{},
 		ThatElvish("-deprecation-level", "42").DoesNothing(),
@@ -76,24 +80,62 @@ func TestShowDeprecations(t *testing.T) {
 	}
 }
 
-func TestNoSuitableSubprogram(t *testing.T) {
-	Test(t, &testProgram{nextProgram: true},
-		ThatElvish().
-			ExitsWith(2).
-			WritesStderr("internal error: no suitable subprogram\n"),
-	)
-}
-
 func TestComposite(t *testing.T) {
 	Test(t,
-		Composite(&testProgram{nextProgram: true}, &testProgram{writeOut: "program 2"}),
+		Composite(
+			&testProgram{returnErr: NextProgram()},
+			&testProgram{writeOut: "program 2"}),
 		ThatElvish().WritesStdout("program 2"),
 	)
 }
 
 func TestComposite_NoSuitableSubprogram(t *testing.T) {
 	Test(t,
-		Composite(&testProgram{nextProgram: true}, &testProgram{nextProgram: true}),
+		Composite(
+			&testProgram{returnErr: NextProgram()},
+			&testProgram{returnErr: NextProgram()}),
+		ThatElvish().
+			ExitsWith(2).
+			WritesStderr("internal error: no suitable subprogram\n"),
+	)
+}
+
+func TestComposite_RunsCleanupsIfAnyProgramIsRun(t *testing.T) {
+	Test(t,
+		Composite(
+			&testProgram{returnErr: NextProgram(func(fds [3]*os.File) {
+				fds[1].WriteString("program 1 cleanup\n")
+			})},
+			&testProgram{returnErr: NextProgram(func(fds [3]*os.File) {
+				fds[1].WriteString("program 2 cleanup\n")
+			})},
+			&testProgram{writeOut: "program 3\n"}),
+		ThatElvish().
+			WritesStdout("program 3\nprogram 2 cleanup\nprogram 1 cleanup\n"),
+	)
+}
+
+func TestComposite_RunsCleanupsEvenIfProgramReturnsError(t *testing.T) {
+	Test(t,
+		Composite(
+			&testProgram{returnErr: NextProgram(func(fds [3]*os.File) {
+				fds[1].WriteString("program 1 cleanup\n")
+			})},
+			&testProgram{returnErr: errors.New("program 2 error")}),
+		ThatElvish().
+			ExitsWith(2).
+			WritesStderr("program 2 error\n").
+			WritesStdout("program 1 cleanup\n"),
+	)
+}
+
+func TestComposite_SkipsCleanupsIfAllProgramsReturnNextProgram(t *testing.T) {
+	Test(t,
+		Composite(
+			&testProgram{returnErr: NextProgram(func(fds [3]*os.File) {
+				fds[1].WriteString("program 1 cleanup\n")
+			})},
+			&testProgram{returnErr: NextProgram()}),
 		ThatElvish().
 			ExitsWith(2).
 			WritesStderr("internal error: no suitable subprogram\n"),
@@ -103,7 +145,8 @@ func TestComposite_NoSuitableSubprogram(t *testing.T) {
 func TestComposite_PreferEarlierSubprogram(t *testing.T) {
 	Test(t,
 		Composite(
-			&testProgram{writeOut: "program 1"}, &testProgram{writeOut: "program 2"}),
+			&testProgram{writeOut: "program 1"},
+			&testProgram{writeOut: "program 2"}),
 		ThatElvish().WritesStdout("program 1"),
 	)
 }
@@ -128,7 +171,6 @@ func TestExitError_0(t *testing.T) {
 }
 
 type testProgram struct {
-	nextProgram bool
 	writeOut    string
 	returnErr   error
 	customFlag  bool
@@ -150,8 +192,8 @@ func (p *testProgram) RegisterFlags(f *FlagSet) {
 }
 
 func (p *testProgram) Run(fds [3]*os.File, args []string) error {
-	if p.nextProgram {
-		return ErrNextProgram
+	if p.returnErr != nil {
+		return p.returnErr
 	}
 	fds[1].WriteString(p.writeOut)
 	if p.customFlag {
@@ -161,5 +203,5 @@ func (p *testProgram) Run(fds [3]*os.File, args []string) error {
 		fmt.Fprintf(fds[1], "-sock %s -db %s -json %v\n",
 			p.daemonPaths.Sock, p.daemonPaths.DB, *p.json)
 	}
-	return p.returnErr
+	return nil
 }
