@@ -19,6 +19,7 @@ import (
 	"src.elv.sh/pkg/parse"
 	"src.elv.sh/pkg/prog"
 	"src.elv.sh/pkg/sys"
+	"src.elv.sh/pkg/ui"
 )
 
 var logger = logutil.GetLogger("[shell] ")
@@ -61,6 +62,8 @@ func (p *Program) Run(fds [3]*os.File, args []string) error {
 	cleanup2 := initSignal(fds)
 	defer cleanup2()
 
+	// https://no-color.org
+	ui.NoColor = os.Getenv(env.NO_COLOR) != ""
 	interactive := len(args) == 0
 	ev := p.makeEvaler(fds[2], interactive)
 	defer ev.PreExit()
@@ -166,8 +169,10 @@ func evalInTTY(fds [3]*os.File, ev *eval.Evaler, ed editor, src parse.Source) er
 	defer cleanup()
 	restore := term.SetupForEval(fds[0], fds[1])
 	defer restore()
+	ctx, done := eval.ListenInterrupts()
 	err := ev.Eval(src, eval.EvalCfg{
-		Ports: ports, Interrupt: eval.ListenInterrupts, PutInFg: true})
+		Ports: ports, Interrupts: ctx, PutInFg: true})
+	done()
 	if ed != nil {
 		ed.RunAfterCommandHooks(src, time.Since(start).Seconds(), err)
 	}
