@@ -1,6 +1,6 @@
 package testutil
 
-func Recover(f func()) (r interface{}) {
+func Recover(f func()) (r any) {
 	defer func() { r = recover() }()
 	f()
 	return
