@@ -3,9 +3,11 @@ package ui
 import (
 	"bytes"
 	"fmt"
+	"math/big"
 	"strings"
 
-	"github.com/elves/elvish/pkg/eval/vals"
+	"src.elv.sh/pkg/eval/vals"
+	"src.elv.sh/pkg/parse"
 )
 
 // Segment is a string that has some style applied to it.
@@ -22,7 +24,7 @@ func (*Segment) Kind() string { return "ui:text-segment" }
 // the Segment represents an unstyled string only this string is returned.
 func (s *Segment) Repr(int) string {
 	buf := new(bytes.Buffer)
-	addIfNotEqual := func(key string, val, cmp interface{}) {
+	addIfNotEqual := func(key string, val, cmp any) {
 		if val != cmp {
 			var valString string
 			if c, ok := val.(Color); ok {
@@ -34,8 +36,8 @@ func (s *Segment) Repr(int) string {
 		}
 	}
 
-	addIfNotEqual("fg-color", s.Foreground, nil)
-	addIfNotEqual("bg-color", s.Background, nil)
+	addIfNotEqual("fg-color", s.Fg, nil)
+	addIfNotEqual("bg-color", s.Bg, nil)
 	addIfNotEqual("bold", s.Bold, false)
 	addIfNotEqual("dim", s.Dim, false)
 	addIfNotEqual("italic", s.Italic, false)
@@ -44,32 +46,32 @@ func (s *Segment) Repr(int) string {
 	addIfNotEqual("inverse", s.Inverse, false)
 
 	if buf.Len() == 0 {
-		return s.Text
+		return parse.Quote(s.Text)
 	}
 
-	return fmt.Sprintf("(ui:text-segment %s %s)", s.Text, strings.TrimSpace(buf.String()))
+	return fmt.Sprintf("(ui:text-segment %s %s)", parse.Quote(s.Text), strings.TrimSpace(buf.String()))
 }
 
 // IterateKeys feeds the function with all valid attributes of styled-segment.
-func (*Segment) IterateKeys(fn func(v interface{}) bool) {
+func (*Segment) IterateKeys(fn func(v any) bool) {
 	vals.Feed(fn, "text", "fg-color", "bg-color", "bold", "dim", "italic", "underlined", "blink", "inverse")
 }
 
 // Index provides access to the attributes of a styled-segment.
-func (s *Segment) Index(k interface{}) (v interface{}, ok bool) {
+func (s *Segment) Index(k any) (v any, ok bool) {
 	switch k {
 	case "text":
 		v = s.Text
 	case "fg-color":
-		if s.Foreground == nil {
+		if s.Fg == nil {
 			return "default", true
 		}
-		return s.Foreground.String(), true
+		return s.Fg.String(), true
 	case "bg-color":
-		if s.Background == nil {
+		if s.Bg == nil {
 			return "default", true
 		}
-		return s.Background.String(), true
+		return s.Bg.String(), true
 	case "bold":
 		v = s.Bold
 	case "dim":
@@ -89,40 +91,27 @@ func (s *Segment) Index(k interface{}) (v interface{}, ok bool) {
 
 // Concat implements Segment+string, Segment+float64, Segment+Segment and
 // Segment+Text.
-func (s *Segment) Concat(v interface{}) (interface{}, error) {
+func (s *Segment) Concat(v any) (any, error) {
 	switch rhs := v.(type) {
 	case string:
-		return Text{
-			s,
-			&Segment{Text: rhs},
-		}, nil
-	case float64:
-		return Text{
-			s,
-			&Segment{Text: vals.ToString(rhs)},
-		}, nil
+		return Text{s, &Segment{Text: rhs}}, nil
 	case *Segment:
 		return Text{s, rhs}, nil
 	case Text:
 		return Text(append([]*Segment{s}, rhs...)), nil
+	case int, *big.Int, *big.Rat, float64:
+		return Text{s, &Segment{Text: vals.ToString(rhs)}}, nil
 	}
-
 	return nil, vals.ErrConcatNotImplemented
 }
 
 // RConcat implements string+Segment and float64+Segment.
-func (s *Segment) RConcat(v interface{}) (interface{}, error) {
+func (s *Segment) RConcat(v any) (any, error) {
 	switch lhs := v.(type) {
 	case string:
-		return Text{
-			&Segment{Text: lhs},
-			s,
-		}, nil
-	case float64:
-		return Text{
-			&Segment{Text: vals.ToString(lhs)},
-			s,
-		}, nil
+		return Text{&Segment{Text: lhs}, s}, nil
+	case int, *big.Int, *big.Rat, float64:
+		return Text{&Segment{Text: vals.ToString(lhs)}, s}, nil
 	}
 	return nil, vals.ErrConcatNotImplemented
 }
@@ -156,11 +145,12 @@ func (s *Segment) String() string {
 	return s.VTString()
 }
 
-// VTString renders the styled segment using VT-style escape sequences.
+// VTString renders the styled segment using VT-style escape sequences. Any
+// existing SGR state will be cleared.
 func (s *Segment) VTString() string {
 	sgr := s.SGR()
 	if sgr == "" {
-		return s.Text
+		return "\033[m" + s.Text
 	}
-	return fmt.Sprintf("\033[%sm%s\033[m", sgr, s.Text)
+	return fmt.Sprintf("\033[;%sm%s\033[m", sgr, s.Text)
 }
